Struct ASlice

pub struct ASlice<T> { /* private fields */ }
A slice of stored AId<T>s inside a HtmlAllocator.

Implementations

Source

impl<'a, T: AllocatorType> ASlice<T>

pub fn len(&self) -> u32

pub fn iter_node( &self, allocator: &'a HtmlAllocator, ) -> ASliceNodeIterator<'a, T>

pub fn iter_att(&self, allocator: &'a HtmlAllocator) -> ASliceAttIterator<'a, T>

pub fn iter_aid(&self, allocator: &'a HtmlAllocator) -> ASliceAIdIterator<'a, T>

pub fn try_filter_map<F: Fn(AId<T>) -> Result<Option<AId<T>>>>( &self, f: F, capacity: Option<u32>, allocator: &'a HtmlAllocator, ) -> Result<AVec<'a, T>>

pub fn split_when<F: Fn(AId<T>) -> bool>( &self, f: F, allocator: &'a HtmlAllocator, ) -> Option<(ASlice<T>, ASlice<T>)>

Split the slice before the first element for which f returns true.

pub fn split_at(&self, i: u32) -> Option<(ASlice<T>, ASlice<T>)>

Split the slice at position i, if that is within the slice.

pub fn first_and_rest( &self, allocator: &'a HtmlAllocator, ) -> Option<(AId<T>, ASlice<T>)>

The first element and the rest, unless the slice is empty.

pub fn get(&self, i: u32, allocator: &'a HtmlAllocator) -> Option<AId<T>>

Source

impl<'a> ASlice<Node>

pub fn unwrap_element_opt( &self, meta: &ElementMeta, strict: bool, allocator: &'a HtmlAllocator, ) -> Option<ASlice<Node>>

If this slice contains only one element of kind meta (and that element has no attributes, if strict is true), returns that element’s body slice.

pub fn unwrap_element( &self, meta: &ElementMeta, strict: bool, allocator: &'a HtmlAllocator, ) -> ASlice<Node>

If this slice contains only one element of kind meta (and that element has no attributes, if strict is true), returns that element’s body slice, otherwise itself.

pub fn unwrap_elements( &self, meta: &ElementMeta, strict: bool, allocator: &'a HtmlAllocator, ) -> Result<ASlice<Node>>

Unwrap even if there are multiple elements, unwrap all of those matching meta.

Source

impl<'a, T: AllocatorType> ASlice<T>

pub fn try_flat_map<F: Fn(AId<T>) -> Result<Flat<T>>>( &self, f: F, capacity: Option<u32>, allocator: &'a HtmlAllocator, ) -> Result<AVec<'a, T>>