Struct HtmlAllocator

pub struct HtmlAllocator { /* private fields */ }

Implementations

Source

impl HtmlAllocator

pub fn new_with_metadb( max_allocations: u32, metadb: Option<&'static MetaDb>, context: Context, ) -> Self

max_allocations: how many node (text, elements, empty nodes) and attribute allocations in total are allowed before out of memory errors are being returned for allocations (i.e. when creating new elements, attributes, or pushing to an AVec). metadb: if given, HTML structure is verified during element allocation.

pub fn clear(&mut self)

pub fn regionid(&self) -> RegionId

pub fn assert_regionid(&self, rid: RegionId)

pub fn get_node<'a>(&'a self, id: AId<Node>) -> Option<&'a Node>

pub fn get_att<'a>( &'a self, id: AId<(KString, KString)>, ) -> Option<&'a (KString, KString)>

pub fn get_id<T: AllocatorType>(&self, id_bare: u32) -> Option<AId<T>>

pub fn new_vec<'a, T: AllocatorType>(&'a self) -> AVec<'a, T>

pub fn new_vec_with_capacity<'a, T: AllocatorType>( &'a self, capacity: u32, ) -> Result<AVec<'a, T>>

pub fn new_element( &self, meta: &'static ElementMeta, attr: ASlice<(KString, KString)>, body: ASlice<Node>, ) -> Result<AId<Node>>

But also see element method for more comfort.

pub fn allocate_element(&self, elt: Element) -> Result<AId<Node>>

pub fn empty_node(&self) -> Result<AId<Node>>

pub fn new_attribute( &self, att: (KString, KString), ) -> Result<AId<(KString, KString)>>

pub fn attribute<K, V>(&self, key: K, val: V) -> Result<AId<(KString, KString)>>
where KString: MyFrom<K> + MyFrom<V>,

pub fn preserialized(&self, val: SerHtmlFrag) -> Result<AId<Node>>

pub fn staticstr(&self, s: &'static str) -> Result<AId<Node>>

pub fn str(&self, s: &str) -> Result<AId<Node>>

pub fn text<T>(&self, s: T) -> Result<AId<Node>>
where KString: MyFrom<T>,

Create a text node (i.e. put the given string into the allocator, return the id to it)

pub fn text_slice<T>(&self, s: T) -> Result<ASlice<Node>>
where KString: MyFrom<T>,

Like text but returns an ASlice containing the single text node, for contexts that expect a slice (i.e. any number of nodes).

pub fn string(&self, s: String) -> Result<AId<Node>>

pub fn opt_string(&self, s: Option<String>) -> Result<AId<Node>>

pub fn kstring(&self, s: KString) -> Result<AId<Node>>

pub fn element( &self, meta: &'static ElementMeta, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

Create an element from normal slices or arrays, for nice to use syntax.

pub fn nbsp(&self) -> Result<AId<Node>>

A text node with just a non-breaking space.

pub fn empty_slice<T>(&self) -> ASlice<T>

Source

impl HtmlAllocator

pub fn new(max_allocations: u32, context: Context) -> Self

Source

impl HtmlAllocator

pub fn html_escape(&self, bytes: &[u8]) -> RefMut<'_, Vec<u8>>

bytes must represent proper UTF-8, e.g. string.as_bytes(). The resulting reference must be dropped before calling html_escape again, or there will be a panic.

pub fn print_html_fragment( &self, id_: AId<Node>, out: &mut impl Write, ) -> Result<()>

pub fn print_html_document( &self, id_: AId<Node>, out: &mut impl Write, ) -> Result<()>

pub fn to_html_string(&self, id: AId<Node>, want_doctype: bool) -> String

pub fn preserialize(&self, id: AId<Node>) -> Result<SerHtmlFrag>

Returns an error if id doesn’t refer to an Element Node.

pub fn print_plain(&self, id: AId<Node>, out: &mut String) -> Result<()>

pub fn to_plain_string(&self, id: AId<Node>) -> Result<KString>

If you need this to strip html and use the result as AId, be sure to use to_plain_string_aid instead, as that optimizes the case of id already representing a string.

pub fn to_plain_string_aid(&self, id: AId<Node>) -> Result<AId<Node>>

Like to_plain_string but returns a string node (or empty node if the input is empty) and optimizes (and silences) the case where id already represents a string.

Source

impl HtmlAllocator

pub fn a( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn abbr( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn address( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn area( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn article( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn aside( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn audio( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn b( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn base( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn bdi( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn bdo( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn blockquote( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn body( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn br( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn button( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn canvas( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn caption( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn cite( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn code( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn col( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn colgroup( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn data( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn datalist( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn dd( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn del( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn details( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn dfn( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn dialog( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn div( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn dl( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn dt( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn em( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn embed( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn fieldset( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn figcaption( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn figure( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn footer( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn form( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h1( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h2( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h3( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h4( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h5( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn h6( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn head( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn header( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn hgroup( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn hr( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn html( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn i( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn iframe( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn img( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn input( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn ins( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn kbd( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn label( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn legend( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn li( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn main( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn map( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn mark( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn menu( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn meta( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn meter( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn nav( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn noscript( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn object( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn ol( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn optgroup( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn option( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn output( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn p( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn picture( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn pre( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn progress( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn q( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn rp( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn rt( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn ruby( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn s( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn samp( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn script( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn search( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn section( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn select( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn slot( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn small( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn source( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn span( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn strong( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn style( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn sub( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn summary( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn sup( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn table( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn tbody( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn td( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn template( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn textarea( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn tfoot( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn th( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn thead( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn time( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn title( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn tr( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn track( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn u( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn ul( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn var( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn video( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>

pub fn wbr( &self, attr: impl ToASlice<(KString, KString)>, body: impl ToASlice<Node>, ) -> Result<AId<Node>>